<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>འཕུར་བའི་རྣམ་པ་ཕྱེ་བ།</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>འཕུར་བའི་རྣམ་པ་ཁ་རྒྱག་པ།</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>སྒོ་རྒྱག་པ།</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>ཁ་འབྱེད།</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>འཕུར་སྐྱོད་དཔེ་རྣམ།</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>འཕུར་སྐྱོད་དཔེ་རྣམ་སྒྲིག་འགོད།</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>འཕུར་སྐྱོད་དཔེ་རྣམ།</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>ངའི་སྒྲིག་ཆས།</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>སོ་སྔོན་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>སོ་སྔོན་ཁ་རྒྱོབ།</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>སོ་སྔོན་ཁ་རྒྱོབ།</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>སོ་སྔོན་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>སོ་སྔོན་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1མཐུད་ཟིན།</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>སྦྲེལ་བཞིན་པ། </translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>སོ་སྔོན།</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>སོ་སྔོན་ཁ་རྒྱོབ།</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>%1སྦྲེལ་ཟིན། </translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>སྦྲེལ་མེད་པ། </translation>
    </message>
    <message>
        <source>Off</source>
        <translation>སྒོ་བརྒྱབ།</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>སོ་སྔོན།</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>གསལ་ཚད།</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>བཪྙན་ཡོལ་སྒྲིག་འགོད།</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>བཪྙན་ཡོལ་སྒྲིག་འགོད།</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>གསལ་ཚད།</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>ཉི་མ།</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>ཟླ་བ།</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>མིག་དམར།</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>ལྷག་པ།</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>ཕུར་བུ།</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>པ་སངས།</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>སྤེན་པ།</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>མཐེབ་གཞོང་བཀོད་པ་སྣོན་པ།</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>དུས་ཚོད།</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>ཆུ་ཚོད་12ཀྱི་ལུགས།</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>ཆུ་ཚོད་24ཡི་ལུགས། </translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>དུས་ཚོད་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>ལོ་ཐོ་ལྟ་བ།</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>གཟའ་ཟླ་བ།</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>གཟའ་མིག་དམར།</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>གཟའ་ལྷག་པ།</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>གཟའ་ཕུར་བུ།</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>གཟའ་པ་སངས།</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>གཟའ་སྤེན་པ།</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>གཟའ་ཉི་མ།</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>གཟའ་ཟླ་བ། </translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>གཟའ་མིག་དམར།</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>གཟའ་ལྷག་པ།</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>གཟའ་ཕུར་བུ།</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>གཟའ་པ་སངས།</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>གཟའ་སྤེན་པ།</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>གཟའ་ཉི་མ།</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>སྒྲིག་ཆས་གཞན།</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>སུན་འགོག་དཔེ་རྣམ།</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>སུན་འགོག་དཔེ་རྣམ་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>སྒོ་རྒྱག་པ།</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>ཁ་འབྱེད།</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>སུན་འགོག་དཔེ་རྣམ་སྒོ་ཕྱེ།</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>སུན་འགོག་དཔེ་རྣམ་སྒོ་རྒྱོབ།</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>སུན་འགོག་དཔེ་རྣམ།</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>མིག་སྲུང་རྣམ་པ།</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>མིག་སྲུང་དཔེ་རྣམ་སྒོ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>མིག་སྲུང་དཔེ་རྣམ་སྒོ་རྒྱོབ།</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>མངོན་སྟོན་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>མིག་སྲུང་རྣམ་པ།</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>བརྗོད་གཞི། </translation>
    </message>
    <message>
        <source>On</source>
        <translation>འགོ་སློང་།</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>སྒོ་བརྒྱབ།</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>མདོག་ཧར་པོ།</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>མདོག་སྣུམ་་པོ།</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>རང་འགུལ།</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>མིག་སྲུང་དཔེ་རྣམ་སྒོ་རྒྱག་པ།</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>མིག་སྲུང་དཔེ་རྣམ་ཕྱེ་བ།</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>མངོན་སྟོན་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>བརྗོད་གཞི།  མདོག་ཧར་པོ།</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>བརྗོད་གཞི། མདོག་སྣུམ་་པོ།</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>བརྗོད་གཞི། རང་འགུལ།</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>མཐོང་ཚོར།</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>མདོག་ཧར་པོ།</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>མདོག་སྣུམ་་པོ།</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>རང་འགུལ།</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>བརྗོད་གཞི། </translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>བརྡ་འཕྲིན་གསར་པ་མི་འདུག</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>བརྡ་ཐོ་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>བརྡ་ཐོ།</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>སུན་འགོག་དཔེ་རྣམ་ཁ་རྒྱོབ།</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>སུན་འགོག་དཔེ་རྣམ་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>བརྡ་ཐོ།</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>བརྙན་ཡོལ་མཐེབ་གཞོང་།</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>སྒྲིག་འགོད།</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>ནུས་པ་མཐོ་བའི་དཔེ་རྣམ།</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>དོ་མཉམ་དཔེ་རྣམ།</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>ནུས་ཁུངས་གྲོན་ཆུང་གི་དཔེ་རྣམ།</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>གློག་ཁུངས་དོ་དམ།</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>གློག་ཁུངས་སྒིག་འགོད།</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>གློག་ཚད་%1 སྐར་མ་%2ལྷག་འདུག</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>གློག་ཚད་%1 ཆུ་ཚོད་%2དང་སྐར་མ་%3ལྷག་འདུག</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>གློག་གསོག་བཞིན་ཡོད་%1 ད་དུང་སྐར་མ་%2དགོས།</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>གློག་གསོག་བཞིན་ཡོད་%1 ད་དུང་ཆུ་ཚོད་%2དང་སྐར་མ་%3དགོས།</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>གློག་ཚད་%1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>གློག་གསོག་བཞིན་ཡོད་%1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>གློག་ཚད་%1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>གློག་ཚད་%1 ཁེངས་ཟིན།</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>གློག་ཚད་%1དང་། གློག་བསོགས་མེད།</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>གློག་སྨན།</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>གློག་གསོག་བཞིན་པ། གློག་གསོག་པའི་དུས་ཡུན་རྩི་བཞིན་ཡོད། </translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>བེད་སྤྱོད་ཀྱི་དུས་ཚོད་ལྷག་མ་རྩི་བཞིན་པ།</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>སྐར་མ་ལྷག་མ།%1</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>ཆུ་ཚོད་%1དང་སྐར་མ་%2ལྷག་པ།</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>གློག་གསག་མེད།</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>གློག་བསགས་པ།</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>གློག་གསོག་བཞིན་ཡོད། ད་དུང་སྐར་མ་%1དགོས།</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>གློག་གསོག་བཞིན་ཡོད། ད་དུང་ཆུ་ཚོད་%1དང་སྐར་མ་%2དགོས།</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>གློག་ཚད་%1 ཆུ་ཚོད་%2ལྷག་འདུག</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>ཆུ་ཚོད་ལྷག་མ།%1</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>གློག་གསོག་བཞིན་ཡོད་%1 ད་དུང་ཆུ་ཚོད་%2དགོས།</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>གློག་གསོག་བཞིན་ཡོད། ད་དུང་ཆུ་ཚོད་%1དགོས།</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>གློག་ཁུངས་སྒིག་འགོད།</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>རོལ་མོ། </translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>མ་ཤེས།</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>རྩིས་འཁོར་གློག་གསོད།</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>སྒུག་སྡོད།</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>མལ་གསོ།</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>བརྙན་ཡོལ་ཟྭ་རྒྱག</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>ཐོ་སུབ་པ།</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>གློག་ཁུངས་སྒིག་འགོད།</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>བསྐྱར་སློང་།</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>གསར་སྒྱུར་དང་སྦྲགས་སྒོ་རྒྱག་པ།</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>གསར་སྒྱུར་དང་སྦྲགས་བསྐྱར་དུ་འགོ་སློང་བ།</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>ཁ་བརྒྱབ།</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>སྤྱོད་མཁན་བརྗེ་བ།</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>དེ་རིང་།</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>ལུགས་རྙིང་ལོ་ཐོ།</translation>
    </message>
    <message>
        <source>y</source>
        <translation>ལོ།</translation>
    </message>
    <message>
        <source>m</source>
        <translation>ཟླ་བ།</translation>
    </message>
    <message>
        <source>d</source>
        <translation>ཚེས།</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>གཟའ་ཟླ་བ།</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>གཟའ་མིག་དམར།</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>གཟའ་ལྷག་པ།</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>གཟའ་ཕུར་བུ།</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>གཟའ་པ་སངས།</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>གཟའ་སྤེན་པ།</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>གཟའ་ཉི་མ།</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>ཟླ་བ་དང་པོ།</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>ཟླ་བ་གཉིས་པ།</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>ཟླ་བ་གསུམ་པ།</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>ཟླ་བ་བཞི་པ།</translation>
    </message>
    <message>
        <source>May</source>
        <translation>ཟླ་བ་ལྔ་པ།</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>ཟླ་བ་དྲུག་པ།</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>ཟླ་བ་བདུན་པ།</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>ཟླ་བ་བརྒྱད་པ།</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>ཟླ་བ་དགུ་པ།</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>ཟླ་བ་བཅུ་པ།</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>ཟླ་བ་བཅུ་གཅིག</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>ཟླ་བ་བཅུ་གཉིས།</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>ལོ་ཐོ་ལྟ་བ།</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>གཟའ་ཟླ་བ། </translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>གཟའ་མིག་དམར།</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>གཟའ་ལྷག་པ།</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>གཟའ་ཕུར་བུ།</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>གཟའ་པ་སངས།</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>གཟའ་སྤེན་པ།</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>གཟའ་ཉི་མ།</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>སྒྲ་ཤུགས།</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>ཕྱིར་འདྲེན།</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>སྐད་གདངས་སྒྲིག་འགོད།</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>སྒྲ།</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>སྒྲ་ལྡན།</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>སྒྲ་མེད།</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>སྐད་གདངས་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>སྒྲ་འདོན་པའི་སྒྲིག་ཆས་མེད།</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>མིག་སྔའི་སྐད་གདངས་%1</translation>
    </message>
</context>
</TS>